##  Overview
Architecture decisions enable you to document, track, and align your organization’s decisions on enterprise architecture directly within SAP LeanIX. By managing architecture decisions within the context of your overall enterprise architecture landscape, you can promote efficiency and achieve better alignment across teams. This feature is designed to mitigate common challenges such as fragmented information in separate tools, inconsistent documentation, and disconnection from the decision-making process.
Architecture decisions provide a convenient way to document and discuss various scenarios and options for transformation initiatives before defining the road map in detail. Key decision-makers, such as lead enterprise architects, can collaboratively review and then approve or reject decisions, defining the overall enterprise architecture strategy for their organization. Approved decisions serve as a foundation for creating subsequent initiatives for transformation projects, providing relevant context and outlining key details.
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_peui7puc/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Farchitecture-decisions%3Fversion%3DCLOUD)
**Note**
Architecture decisions are only available to customers using SAP LeanIX Architecture and Road Map Planning. To learn how to manage transformations using this product, see [Getting Started with SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "Explore these foundational steps to kickstart your SAP LeanIX Architecture and Road Map Planning experience and begin the transformative process for your initiatives.").
